@@ -1,7 +1,7 @@
 package App::grepcoin;
 
-our $DATE = '2018-01-26'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2018-01-30'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,7 +22,17 @@ Greps list of coins from <pm:CryptoCurrency::Catalog>, which in turn gets its
 list from <https://coinmarketcap.com/>.
 
 _
-    add_args    => {
+    remove_args => ['pattern'],
+    modify_args => {
+        regexps => sub {
+            my $arg = shift;
+            $arg->{pos} = 0;
+            $arg->{greedy} = 1;
+        },
+        ignore_case => sub {
+            my $arg = shift;
+            $arg->{default} = 1;
+        },
     },
     output_code => sub {
         require CryptoCurrency::Catalog;
@@ -62,7 +72,7 @@ App::grepcoin - Grep cryptocurrency coins
 
 =head1 VERSION
 
-This document describes version 0.005 of App::grepcoin (from Perl distribution App-CryptoCurrencyUtils), released on 2018-01-26.
+This document describes version 0.006 of App::grepcoin (from Perl distribution App-CryptoCurrencyUtils), released on 2018-01-30.
 
 =head1 FUNCTIONS
 
@@ -84,22 +94,28 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<color> => I<str> (default: "auto")
+=item * B<all> => I<true>
+
+Require all patterns to match, instead of just one.
+
+=item * B<color> => I<str>
 
 =item * B<count> => I<true>
 
 Supress normal output, return a count of matching lines.
 
-=item * B<ignore_case> => I<bool>
+=item * B<ignore_case> => I<bool> (default: 1)
 
 =item * B<invert_match> => I<bool>
 
 Invert the sense of matching.
 
-=item * B<pattern>* => I<re>
+=item * B<line_number> => I<true>
 
 =item * B<quiet> => I<true>
 
+=item * B<regexps> => I<array[re]>
+
 =back
 
 Returns an enveloped result (an array).
